@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.contrib.sites.models import Site
+from django.conf import settings
 
 
 def get_site_url(request, slash=False):
@@ -12,9 +13,13 @@ def get_site_url(request, slash=False):
 
 
 def absolute(request):
-    return {
+    urls = {
         'ABSOLUTE_ROOT': request.build_absolute_uri('/')[:-1],
         'ABSOLUTE_ROOT_URL': request.build_absolute_uri('/'),
-        'SITE_ROOT': get_site_url(request),
-        'SITE_ROOT_URL': get_site_url(request, True),
     }
+    
+    if 'django.contrib.sites' in settings.INSTALLED_APPS:
+        urls['SITE_ROOT'] = get_site_url(request)
+        urls['SITE_ROOT_URL'] = get_site_url(request, True)
+    
+    return urls
\ No newline at end of file
